=========
CHANGELOG
=========

Version 1.1.4
=============

* Revamp migrations to Django 1.7 format

Version 1.1.3
=============

* Fix setup.py to properly install

Version 1.1.2
=============

* First release of package to include this CHANGELOG.
